@@ -15,7 +15,7 @@ namespace SourceGit.Commands
         {
             WorkingDirectory = repo;
             Context = repo;
-            Args = "branch -l --all -v --format=\"%(refname)%00%(committerdate:unix)%00%(objectname)%00%(HEAD)%00%(upstream)%00%(upstream:trackshort)\"";
+            Args = "branch -l --all -v --format=\"%(refname)%00%(committerdate:unix)%00%(objectname)%00%(HEAD)%00%(upstream)%00%(upstream:trackshort)%00%(worktreepath)\"";
         }
 
         public async Task<List<Models.Branch>> GetResultAsync()
@@ -26,15 +26,16 @@ namespace SourceGit.Commands
                 return branches;
 
             var lines = rs.StdOut.Split(['\r', '\n'], StringSplitOptions.RemoveEmptyEntries);
-            var remoteHeads = new Dictionary<string, string>();
+            var mismatched = new HashSet<string>();
+            var remotes = new Dictionary<string, Models.Branch>();
             foreach (var line in lines)
             {
-                var b = ParseLine(line);
+                var b = ParseLine(line, mismatched);
                 if (b != null)
                 {
                     branches.Add(b);
                     if (!b.IsLocal)
-                        remoteHeads.Add(b.FullName, b.Head);
+                        remotes.Add(b.FullName, b);
                 }
             }
 
@@ -42,15 +43,16 @@ namespace SourceGit.Commands
             {
                 if (b.IsLocal && !string.IsNullOrEmpty(b.Upstream))
                 {
-                    if (remoteHeads.TryGetValue(b.Upstream, out var upstreamHead))
+                    if (remotes.TryGetValue(b.Upstream, out var upstream))
                     {
                         b.IsUpstreamGone = false;
-                        b.TrackStatus ??= await new QueryTrackStatus(WorkingDirectory, b.Head, upstreamHead).GetResultAsync().ConfigureAwait(false);
+
+                        if (mismatched.Contains(b.FullName))
+                            await new QueryTrackStatus(WorkingDirectory).GetResultAsync(b, upstream).ConfigureAwait(false);
                     }
                     else
                     {
                         b.IsUpstreamGone = true;
-                        b.TrackStatus ??= new Models.BranchTrackStatus();
                     }
                 }
             }
@@ -58,10 +60,10 @@ namespace SourceGit.Commands
             return branches;
         }
 
-        private Models.Branch ParseLine(string line)
+        private Models.Branch ParseLine(string line, HashSet<string> mismatched)
         {
             var parts = line.Split('\0');
-            if (parts.Length != 6)
+            if (parts.Length != 7)
                 return null;
 
             var branch = new Models.Branch();
@@ -94,19 +96,22 @@ namespace SourceGit.Commands
                 branch.IsLocal = true;
             }
 
+            ulong.TryParse(parts[1], out var committerDate);
+
             branch.FullName = refName;
-            branch.CommitterDate = ulong.Parse(parts[1]);
+            branch.CommitterDate = committerDate;
             branch.Head = parts[2];
             branch.IsCurrent = parts[3] == "*";
             branch.Upstream = parts[4];
             branch.IsUpstreamGone = false;
 
-            if (!branch.IsLocal ||
-                string.IsNullOrEmpty(branch.Upstream) ||
-                string.IsNullOrEmpty(parts[5]) ||
-                parts[5].Equals("=", StringComparison.Ordinal))
-                branch.TrackStatus = new Models.BranchTrackStatus();
+            if (branch.IsLocal &&
+                !string.IsNullOrEmpty(branch.Upstream) &&
+                !string.IsNullOrEmpty(parts[5]) &&
+                !parts[5].Equals("=", StringComparison.Ordinal))
+                mismatched.Add(branch.FullName);
 
+            branch.WorktreePath = parts[6];
             return branch;
         }
     }
