@@ -5,31 +5,28 @@ namespace SourceGit.Commands
 {
     public class QueryTrackStatus : Command
     {
-        public QueryTrackStatus(string repo, string local, string upstream)
+        public QueryTrackStatus(string repo)
         {
             WorkingDirectory = repo;
             Context = repo;
-            Args = $"rev-list --left-right {local}...{upstream}";
         }
 
-        public async Task<Models.BranchTrackStatus> GetResultAsync()
+        public async Task GetResultAsync(Models.Branch local, Models.Branch remote)
         {
-            var status = new Models.BranchTrackStatus();
+            Args = $"rev-list --left-right {local.Head}...{remote.Head}";
 
             var rs = await ReadToEndAsync().ConfigureAwait(false);
             if (!rs.IsSuccess)
-                return status;
+                return;
 
             var lines = rs.StdOut.Split(['\r', '\n'], StringSplitOptions.RemoveEmptyEntries);
             foreach (var line in lines)
             {
                 if (line[0] == '>')
-                    status.Behind.Add(line.Substring(1));
+                    local.Behind.Add(line.Substring(1));
                 else
-                    status.Ahead.Add(line.Substring(1));
+                    local.Ahead.Add(line.Substring(1));
             }
-
-            return status;
         }
     }
 }
