@@ -23,7 +23,7 @@ namespace SourceGit.ViewModels
 
         public override async Task<bool> Sure()
         {
-            _repo.SetWatcherEnabled(false);
+            using var lockWatcher = _repo.LockWatcher();
             ProgressDescription = "Fast-Forward ...";
 
             var log = _repo.CreateLog($"Fetch Into '{Local.FriendlyName}'");
@@ -37,7 +37,6 @@ namespace SourceGit.ViewModels
 
             var newHead = await new Commands.QueryRevisionByRefName(_repo.FullPath, Local.Name).GetResultAsync();
             _repo.NavigateToCommit(newHead, true);
-            _repo.SetWatcherEnabled(true);
             return true;
         }
 
