@@ -50,25 +50,27 @@ namespace SourceGit.Views
 
             if (node.Backend is Models.Remote)
             {
-                CreateContent(new Thickness(0, 0, 0, 0), "Icons.Remote", false);
+                CreateContent(new Thickness(0, 0, 0, 0), "Icons.Remote");
             }
             else if (node.Backend is Models.Branch branch)
             {
                 if (branch.IsCurrent)
-                    CreateContent(new Thickness(0, 0, 0, 0), "Icons.CheckCircled", true);
+                    CreateContent(new Thickness(0, 0, 0, 0), "Icons.CheckCircled", Brushes.Green);
+                else if (branch.IsLocal && !string.IsNullOrEmpty(branch.WorktreePath))
+                    CreateContent(new Thickness(2, 0, 0, 0), "Icons.Branch", Brushes.DarkCyan);
                 else
-                    CreateContent(new Thickness(2, 0, 0, 0), "Icons.Branch", false);
+                    CreateContent(new Thickness(2, 0, 0, 0), "Icons.Branch");
             }
             else
             {
                 if (node.IsExpanded)
-                    CreateContent(new Thickness(0, 2, 0, 0), "Icons.Folder.Open", false);
+                    CreateContent(new Thickness(0, 2, 0, 0), "Icons.Folder.Open");
                 else
-                    CreateContent(new Thickness(0, 2, 0, 0), "Icons.Folder", false);
+                    CreateContent(new Thickness(0, 2, 0, 0), "Icons.Folder");
             }
         }
 
-        private void CreateContent(Thickness margin, string iconKey, bool highlight)
+        private void CreateContent(Thickness margin, string iconKey, IBrush fill = null)
         {
             if (this.FindResource(iconKey) is not StreamGeometry geo)
                 return;
@@ -83,8 +85,8 @@ namespace SourceGit.Views
                 Data = geo,
             };
 
-            if (highlight)
-                path.Fill = Brushes.Green;
+            if (fill != null)
+                path.Fill = fill;
 
             Content = path;
         }
@@ -181,11 +183,11 @@ namespace SourceGit.Views
 
             if (DataContext is ViewModels.BranchTreeNode { Backend: Models.Branch branch })
             {
-                var status = branch.TrackStatus.ToString();
-                if (!string.IsNullOrEmpty(status))
+                var desc = branch.TrackStatusDescription;
+                if (!string.IsNullOrEmpty(desc))
                 {
                     _label = new FormattedText(
-                        status,
+                        desc,
                         CultureInfo.CurrentCulture,
                         FlowDirection.LeftToRight,
                         new Typeface(FontFamily),
@@ -200,6 +202,33 @@ namespace SourceGit.Views
         private FormattedText _label = null;
     }
 
+    public class BranchTreeNodeTrackStatusTooltip : TextBlock
+    {
+        protected override Type StyleKeyOverride => typeof(TextBlock);
+
+        protected override void OnDataContextChanged(EventArgs e)
+        {
+            base.OnDataContextChanged(e);
+
+            Text = string.Empty;
+
+            if (DataContext is not Models.Branch { IsTrackStatusVisible: true } branch)
+            {
+                SetCurrentValue(IsVisibleProperty, false);
+                return;
+            }
+
+            var ahead = branch.Ahead.Count;
+            var behind = branch.Behind.Count;
+            if (ahead > 0)
+                Text = behind > 0 ? App.Text("BranchTree.AheadBehind", ahead, behind) : App.Text("BranchTree.Ahead", ahead);
+            else
+                Text = App.Text("BranchTree.Behind", behind);
+
+            SetCurrentValue(IsVisibleProperty, true);
+        }
+    }
+
     public partial class BranchTree : UserControl
     {
         public static readonly StyledProperty<List<ViewModels.BranchTreeNode>> NodesProperty =
@@ -352,6 +381,10 @@ namespace SourceGit.Views
 
         private void OnNodePointerPressed(object sender, PointerPressedEventArgs e)
         {
+            var ctrl = OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control;
+            if (e.KeyModifiers.HasFlag(ctrl) || e.KeyModifiers.HasFlag(KeyModifiers.Shift))
+                return;
+
             var p = e.GetCurrentPoint(this);
             if (!p.Properties.IsLeftButtonPressed)
                 return;
@@ -365,13 +398,6 @@ namespace SourceGit.Views
             if (node.Backend is not Models.Branch branch)
                 return;
 
-            if (BranchesPresenter.SelectedItems is { Count: > 0 })
-            {
-                var ctrl = OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control;
-                if (e.KeyModifiers.HasFlag(ctrl) || e.KeyModifiers.HasFlag(KeyModifiers.Shift))
-                    return;
-            }
-
             repo.NavigateToCommit(branch.Head);
         }
 
@@ -519,7 +545,7 @@ namespace SourceGit.Views
             e.Handled = true;
         }
 
-        private void OnDoubleTappedBranchNode(object sender, TappedEventArgs _)
+        private async void OnDoubleTappedBranchNode(object sender, TappedEventArgs _)
         {
             if (sender is Grid { DataContext: ViewModels.BranchTreeNode node })
             {
@@ -529,7 +555,7 @@ namespace SourceGit.Views
                         return;
 
                     if (DataContext is ViewModels.Repository { Settings: not null } repo)
-                        repo.CheckoutBranch(branch);
+                        await repo.CheckoutBranchAsync(branch);
                 }
                 else
                 {
@@ -608,11 +634,11 @@ namespace SourceGit.Views
                         var fastForward = new MenuItem();
                         fastForward.Header = App.Text("BranchCM.FastForward", upstream.FriendlyName);
                         fastForward.Icon = App.CreateMenuIcon("Icons.FastForward");
-                        fastForward.IsEnabled = branch.TrackStatus.Ahead.Count == 0 && branch.TrackStatus.Behind.Count > 0;
-                        fastForward.Click += (_, e) =>
+                        fastForward.IsEnabled = branch.Ahead.Count == 0 && branch.Behind.Count > 0;
+                        fastForward.Click += async (_, e) =>
                         {
                             if (repo.CanCreatePopup())
-                                repo.ShowAndStartPopup(new ViewModels.Merge(repo, upstream, branch.Name, true));
+                                await repo.ShowAndStartPopupAsync(new ViewModels.Merge(repo, upstream, branch.Name, true));
                             e.Handled = true;
                         };
 
@@ -636,31 +662,30 @@ namespace SourceGit.Views
             }
             else
             {
-                if (!repo.IsBare)
-                {
-                    var checkout = new MenuItem();
-                    checkout.Header = App.Text("BranchCM.Checkout", branch.Name);
-                    checkout.Icon = App.CreateMenuIcon("Icons.Check");
-                    checkout.Click += (_, e) =>
-                    {
-                        repo.CheckoutBranch(branch);
-                        e.Handled = true;
-                    };
-                    menu.Items.Add(checkout);
-                    menu.Items.Add(new MenuItem() { Header = "-" });
-                }
+                var hasNoWorktree = string.IsNullOrEmpty(branch.WorktreePath);
 
-                var worktree = repo.Worktrees.Find(x => x.Branch == branch.FullName);
-                if (upstream != null && worktree == null)
+                var checkout = new MenuItem();
+                checkout.Header = App.Text(hasNoWorktree ? "BranchCM.Checkout" : "BranchCM.SwitchToWorktree", branch.Name);
+                checkout.Icon = App.CreateMenuIcon("Icons.Check");
+                checkout.IsEnabled = !repo.IsBare || !hasNoWorktree;
+                checkout.Click += async (_, e) =>
+                {
+                    await repo.CheckoutBranchAsync(branch);
+                    e.Handled = true;
+                };
+                menu.Items.Add(checkout);
+                menu.Items.Add(new MenuItem() { Header = "-" });
+
+                if (upstream != null && hasNoWorktree)
                 {
                     var fastForward = new MenuItem();
                     fastForward.Header = App.Text("BranchCM.FastForward", upstream.FriendlyName);
                     fastForward.Icon = App.CreateMenuIcon("Icons.FastForward");
-                    fastForward.IsEnabled = branch.TrackStatus.Ahead.Count == 0 && branch.TrackStatus.Behind.Count > 0;
-                    fastForward.Click += (_, e) =>
+                    fastForward.IsEnabled = branch.Ahead.Count == 0 && branch.Behind.Count > 0;
+                    fastForward.Click += async (_, e) =>
                     {
                         if (repo.CanCreatePopup())
-                            repo.ShowAndStartPopup(new ViewModels.ResetWithoutCheckout(repo, branch, upstream));
+                            await repo.ShowAndStartPopupAsync(new ViewModels.ResetWithoutCheckout(repo, branch, upstream));
                         e.Handled = true;
                     };
                     menu.Items.Add(fastForward);
@@ -668,11 +693,11 @@ namespace SourceGit.Views
                     var fetchInto = new MenuItem();
                     fetchInto.Header = App.Text("BranchCM.FetchInto", upstream.FriendlyName, branch.Name);
                     fetchInto.Icon = App.CreateMenuIcon("Icons.Fetch");
-                    fetchInto.IsEnabled = branch.TrackStatus.Ahead.Count == 0;
-                    fetchInto.Click += (_, e) =>
+                    fetchInto.IsEnabled = branch.Ahead.Count == 0;
+                    fetchInto.Click += async (_, e) =>
                     {
                         if (repo.CanCreatePopup())
-                            repo.ShowAndStartPopup(new ViewModels.FetchInto(repo, branch, upstream));
+                            await repo.ShowAndStartPopupAsync(new ViewModels.FetchInto(repo, branch, upstream));
                         e.Handled = true;
                     };
 
@@ -708,7 +733,7 @@ namespace SourceGit.Views
                     menu.Items.Add(rebase);
                 }
 
-                if (worktree == null)
+                if (hasNoWorktree)
                 {
                     var selectedCommit = repo.GetSelectedCommitInHistory();
                     if (selectedCommit != null && !selectedCommit.SHA.Equals(branch.Head, StringComparison.Ordinal))
@@ -744,7 +769,7 @@ namespace SourceGit.Views
                     compareWithWorktree.Icon = App.CreateMenuIcon("Icons.Compare");
                     compareWithWorktree.Click += async (_, e) =>
                     {
-                        await repo.CompareBranchWithWorktree(branch);
+                        await repo.CompareBranchWithWorktreeAsync(branch);
                         e.Handled = true;
                     };
                     menu.Items.Add(compareWithWorktree);
@@ -894,17 +919,17 @@ namespace SourceGit.Views
             fetch.Click += (_, e) =>
             {
                 if (repo.CanCreatePopup())
-                    repo.ShowAndStartPopup(new ViewModels.Fetch(repo, remote));
+                    repo.ShowPopup(new ViewModels.Fetch(repo, remote));
                 e.Handled = true;
             };
 
             var prune = new MenuItem();
             prune.Header = App.Text("RemoteCM.Prune");
             prune.Icon = App.CreateMenuIcon("Icons.Clean");
-            prune.Click += (_, e) =>
+            prune.Click += async (_, e) =>
             {
                 if (repo.CanCreatePopup())
-                    repo.ShowAndStartPopup(new ViewModels.PruneRemote(repo, remote));
+                    await repo.ShowAndStartPopupAsync(new ViewModels.PruneRemote(repo, remote));
                 e.Handled = true;
             };
 
@@ -943,6 +968,7 @@ namespace SourceGit.Views
             menu.Items.Add(edit);
             menu.Items.Add(delete);
             menu.Items.Add(new MenuItem() { Header = "-" });
+            TryToAddCustomActionsToRemoteContextMenu(repo, menu, remote);
             menu.Items.Add(copy);
             return menu;
         }
@@ -955,9 +981,9 @@ namespace SourceGit.Views
             var checkout = new MenuItem();
             checkout.Header = App.Text("BranchCM.Checkout", name);
             checkout.Icon = App.CreateMenuIcon("Icons.Check");
-            checkout.Click += (_, e) =>
+            checkout.Click += async (_, e) =>
             {
-                repo.CheckoutBranch(branch);
+                await repo.CheckoutBranchAsync(branch);
                 e.Handled = true;
             };
             menu.Items.Add(checkout);
@@ -1017,7 +1043,7 @@ namespace SourceGit.Views
                 compareWithWorktree.Icon = App.CreateMenuIcon("Icons.Compare");
                 compareWithWorktree.Click += async (_, e) =>
                 {
-                    await repo.CompareBranchWithWorktree(branch);
+                    await repo.CompareBranchWithWorktreeAsync(branch);
                     e.Handled = true;
                 };
                 menu.Items.Add(compareWithWorktree);
@@ -1102,9 +1128,38 @@ namespace SourceGit.Views
                 var item = new MenuItem();
                 item.Icon = App.CreateMenuIcon("Icons.Action");
                 item.Header = label;
-                item.Click += (_, e) =>
+                item.Click += async (_, e) =>
                 {
-                    repo.ExecCustomAction(dup, branch);
+                    await repo.ExecCustomActionAsync(dup, branch);
+                    e.Handled = true;
+                };
+
+                custom.Items.Add(item);
+            }
+
+            menu.Items.Add(custom);
+            menu.Items.Add(new MenuItem() { Header = "-" });
+        }
+
+        private void TryToAddCustomActionsToRemoteContextMenu(ViewModels.Repository repo, ContextMenu menu, Models.Remote remote)
+        {
+            var actions = repo.GetCustomActions(Models.CustomActionScope.Remote);
+            if (actions.Count == 0)
+                return;
+
+            var custom = new MenuItem();
+            custom.Header = App.Text("RemoteCM.CustomAction");
+            custom.Icon = App.CreateMenuIcon("Icons.Action");
+
+            foreach (var action in actions)
+            {
+                var (dup, label) = action;
+                var item = new MenuItem();
+                item.Icon = App.CreateMenuIcon("Icons.Action");
+                item.Header = label;
+                item.Click += async (_, e) =>
+                {
+                    await repo.ExecCustomActionAsync(dup, remote);
                     e.Handled = true;
                 };
 
