@@ -4,6 +4,7 @@ using Avalonia;
 using Avalonia.Controls;
 using Avalonia.Input;
 using Avalonia.Interactivity;
+using Avalonia.Media;
 using Avalonia.Platform;
 using Avalonia.VisualTree;
 
@@ -317,6 +318,20 @@ namespace SourceGit.Views
             {
                 var pref = ViewModels.Preferences.Instance;
                 var menu = new ContextMenu();
+                menu.Placement = PlacementMode.BottomEdgeAlignedLeft;
+                menu.VerticalOffset = -6;
+
+                var groupHeader = new TextBlock()
+                {
+                    Text = App.Text("Launcher.Workspaces"),
+                    FontWeight = FontWeight.Bold,
+                };
+
+                var workspaces = new MenuItem();
+                workspaces.Header = groupHeader;
+                workspaces.Tag = OperatingSystem.IsMacOS() ? "⌘+⇧+P" : "Ctrl+Shift+P";
+                workspaces.IsEnabled = false;
+                menu.Items.Add(workspaces);
 
                 for (var i = 0; i < pref.Workspaces.Count; i++)
                 {
@@ -328,12 +343,12 @@ namespace SourceGit.Views
                     var item = new MenuItem();
                     item.Header = workspace.Name;
                     item.Icon = icon;
-                    item.Click += (_, e) =>
+                    item.Click += (_, ev) =>
                     {
                         if (!workspace.IsActive)
                             launcher.SwitchWorkspace(workspace);
 
-                        e.Handled = true;
+                        ev.Handled = true;
                     };
 
                     menu.Items.Add(item);
@@ -343,10 +358,10 @@ namespace SourceGit.Views
 
                 var configure = new MenuItem();
                 configure.Header = App.Text("Workspace.Configure");
-                configure.Click += async (_, e) =>
+                configure.Click += async (_, ev) =>
                 {
                     await App.ShowDialog(new ViewModels.ConfigureWorkspace());
-                    e.Handled = true;
+                    ev.Handled = true;
                 };
                 menu.Items.Add(configure);
                 menu.Open(btn);
