@@ -21,7 +21,7 @@ namespace SourceGit.Views
             }
         }
 
-        private void OnItemDoubleTapped(object sender, TappedEventArgs e)
+        private void OnItemTapped(object sender, TappedEventArgs e)
         {
             if (DataContext is ViewModels.LauncherPageSwitcher switcher)
             {
@@ -32,14 +32,28 @@ namespace SourceGit.Views
 
         private void OnSearchBoxKeyDown(object sender, KeyEventArgs e)
         {
-            if (e.Key == Key.Down && PagesListBox.ItemCount > 0)
+            if (PagesListBox.ItemCount == 0)
+                return;
+
+            if (e.Key == Key.Down)
             {
                 PagesListBox.Focus(NavigationMethod.Directional);
 
-                if (PagesListBox.SelectedIndex < 0)
-                    PagesListBox.SelectedIndex = 0;
-                else if (PagesListBox.SelectedIndex < PagesListBox.ItemCount)
+                if (PagesListBox.SelectedIndex < PagesListBox.ItemCount - 1)
                     PagesListBox.SelectedIndex++;
+                else
+                    PagesListBox.SelectedIndex = 0;
+
+                e.Handled = true;
+            }
+            else if (e.Key == Key.Up)
+            {
+                PagesListBox.Focus(NavigationMethod.Directional);
+
+                if (PagesListBox.SelectedIndex > 0)
+                    PagesListBox.SelectedIndex--;
+                else
+                    PagesListBox.SelectedIndex = PagesListBox.ItemCount - 1;
 
                 e.Handled = true;
             }
