@@ -1,4 +1,5 @@
 using System;
+using System.Collections.Generic;
 
 using Avalonia;
 using Avalonia.Controls;
@@ -143,7 +144,7 @@ namespace SourceGit.Views
                 if (Content is ViewModels.TagCollectionAsTree tree)
                     Rows = tree.Rows.Count;
                 else if (Content is ViewModels.TagCollectionAsList list)
-                    Rows = list.Tags.Count;
+                    Rows = list.TagItems.Count;
                 else
                     Rows = 0;
 
@@ -155,16 +156,30 @@ namespace SourceGit.Views
             }
         }
 
-        private void OnItemDoubleTapped(object sender, TappedEventArgs e)
+        private async void OnItemDoubleTapped(object sender, TappedEventArgs e)
         {
-            if (sender is Control { DataContext: ViewModels.TagTreeNode { IsFolder: true } node })
-                ToggleNodeIsExpanded(node);
+            if (sender is Control { DataContext: ViewModels.TagTreeNode node })
+            {
+                if (node.IsFolder)
+                    ToggleNodeIsExpanded(node);
+                else if (DataContext is ViewModels.Repository repo)
+                    await repo.CheckoutTagAsync(node.Tag);
+            }
+            else if (sender is Control { DataContext: ViewModels.TagListItem item })
+            {
+                if (DataContext is ViewModels.Repository repo)
+                    await repo.CheckoutTagAsync(item.Tag);
+            }
 
             e.Handled = true;
         }
 
         private void OnItemPointerPressed(object sender, PointerPressedEventArgs e)
         {
+            var ctrl = OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control;
+            if (e.KeyModifiers.HasFlag(ctrl) || e.KeyModifiers.HasFlag(KeyModifiers.Shift))
+                return;
+
             var p = e.GetCurrentPoint(this);
             if (!p.Properties.IsLeftButtonPressed)
                 return;
@@ -172,55 +187,64 @@ namespace SourceGit.Views
             if (DataContext is not ViewModels.Repository repo)
                 return;
 
-            if (sender is Control { DataContext: Models.Tag tag })
-                repo.NavigateToCommit(tag.SHA);
-            else if (sender is Control { DataContext: ViewModels.TagTreeNode { Tag: { } nodeTag } })
-                repo.NavigateToCommit(nodeTag.SHA);
-        }
-
-        private void OnItemContextRequested(object sender, ContextRequestedEventArgs e)
-        {
             if (sender is not Control control)
                 return;
 
-            Models.Tag selected;
-            if (control.DataContext is ViewModels.TagTreeNode node)
-                selected = node.Tag;
-            else if (control.DataContext is Models.Tag tag)
-                selected = tag;
-            else
-                selected = null;
+            if (control.DataContext is ViewModels.TagListItem { Tag: { } itemTag })
+                repo.NavigateToCommit(itemTag.SHA);
+            else if (control.DataContext is ViewModels.TagTreeNode { Tag: { } nodeTag })
+                repo.NavigateToCommit(nodeTag.SHA);
+        }
 
-            if (selected != null && DataContext is ViewModels.Repository repo)
+        private void OnTagsContextMenuRequested(object sender, ContextRequestedEventArgs e)
+        {
+            if (sender is not ListBox { SelectedItems: { Count: > 0 } selectedItems } listBox)
+                return;
+
+            if (DataContext is not ViewModels.Repository repo)
+                return;
+
+            var selected = new List<Models.Tag>();
+            foreach (var item in selectedItems)
             {
+                if (item is ViewModels.TagListItem i)
+                    selected.Add(i.Tag);
+                else if (item is ViewModels.TagTreeNode n)
+                    CollectTagsInNode(n, selected);
+            }
+
+            if (selected.Count == 1)
+            {
+                var tag = selected[0];
+
                 var createBranch = new MenuItem();
                 createBranch.Icon = App.CreateMenuIcon("Icons.Branch.Add");
                 createBranch.Header = App.Text("CreateBranch");
                 createBranch.Click += (_, ev) =>
                 {
                     if (repo.CanCreatePopup())
-                        repo.ShowPopup(new ViewModels.CreateBranch(repo, selected));
+                        repo.ShowPopup(new ViewModels.CreateBranch(repo, tag));
                     ev.Handled = true;
                 };
 
                 var pushTag = new MenuItem();
-                pushTag.Header = App.Text("TagCM.Push", selected.Name);
+                pushTag.Header = App.Text("TagCM.Push", tag.Name);
                 pushTag.Icon = App.CreateMenuIcon("Icons.Push");
                 pushTag.IsEnabled = repo.Remotes.Count > 0;
                 pushTag.Click += (_, ev) =>
                 {
                     if (repo.CanCreatePopup())
-                        repo.ShowPopup(new ViewModels.PushTag(repo, selected));
+                        repo.ShowPopup(new ViewModels.PushTag(repo, tag));
                     ev.Handled = true;
                 };
 
                 var deleteTag = new MenuItem();
-                deleteTag.Header = App.Text("TagCM.Delete", selected.Name);
+                deleteTag.Header = App.Text("TagCM.Delete", tag.Name);
                 deleteTag.Icon = App.CreateMenuIcon("Icons.Clear");
                 deleteTag.Click += (_, ev) =>
                 {
                     if (repo.CanCreatePopup())
-                        repo.ShowPopup(new ViewModels.DeleteTag(repo, selected));
+                        repo.ShowPopup(new ViewModels.DeleteTag(repo, tag));
                     ev.Handled = true;
                 };
 
@@ -230,7 +254,7 @@ namespace SourceGit.Views
                 archive.Click += (_, ev) =>
                 {
                     if (repo.CanCreatePopup())
-                        repo.ShowPopup(new ViewModels.Archive(repo, selected));
+                        repo.ShowPopup(new ViewModels.Archive(repo, tag));
                     ev.Handled = true;
                 };
 
@@ -256,10 +280,10 @@ namespace SourceGit.Views
                         var item = new MenuItem();
                         item.Icon = App.CreateMenuIcon("Icons.Action");
                         item.Header = label;
-                        item.Click += (_, e) =>
+                        item.Click += async (_, ev) =>
                         {
-                            repo.ExecCustomAction(dup, selected);
-                            e.Handled = true;
+                            await repo.ExecCustomActionAsync(dup, tag);
+                            ev.Handled = true;
                         };
 
                         custom.Items.Add(item);
@@ -270,27 +294,63 @@ namespace SourceGit.Views
                 }
 
                 var copy = new MenuItem();
-                copy.Header = App.Text("TagCM.Copy");
+                copy.Header = App.Text("Copy");
                 copy.Icon = App.CreateMenuIcon("Icons.Copy");
-                copy.Click += async (_, ev) =>
+
+                var copyName = new MenuItem();
+                copyName.Header = App.Text("TagCM.Copy.Name");
+                copyName.Icon = App.CreateMenuIcon("Icons.Tag");
+                copyName.Click += async (_, ev) =>
                 {
-                    await App.CopyTextAsync(selected.Name);
+                    await App.CopyTextAsync(tag.Name);
                     ev.Handled = true;
                 };
 
                 var copyMessage = new MenuItem();
-                copyMessage.Header = App.Text("TagCM.CopyMessage");
-                copyMessage.Icon = App.CreateMenuIcon("Icons.Copy");
-                copyMessage.IsEnabled = !string.IsNullOrEmpty(selected.Message);
+                copyMessage.Header = App.Text("TagCM.Copy.Message");
+                copyMessage.Icon = App.CreateMenuIcon("Icons.Info");
+                copyMessage.IsEnabled = !string.IsNullOrEmpty(tag.Message);
                 copyMessage.Click += async (_, ev) =>
                 {
-                    await App.CopyTextAsync(selected.Message);
+                    await App.CopyTextAsync(tag.Message);
                     ev.Handled = true;
                 };
 
+                copy.Items.Add(copyName);
+                copy.Items.Add(copyMessage);
+
+                if (tag.Creator is { Email: { Length: > 0 } })
+                {
+                    var copyCreator = new MenuItem();
+                    copyCreator.Header = App.Text("TagCM.Copy.Tagger");
+                    copyCreator.Icon = App.CreateMenuIcon("Icons.User");
+                    copyCreator.Click += async (_, ev) =>
+                    {
+                        await App.CopyTextAsync(tag.Creator.ToString());
+                        ev.Handled = true;
+                    };
+                    copy.Items.Add(copyCreator);
+                }
+
                 menu.Items.Add(copy);
-                menu.Items.Add(copyMessage);
-                menu.Open(control);
+                menu.Open(listBox);
+            }
+            else if (selected.Count > 0)
+            {
+                var deleteMultiple = new MenuItem();
+                deleteMultiple.Header = App.Text("TagCM.DeleteMultiple", selected.Count);
+                deleteMultiple.Icon = App.CreateMenuIcon("Icons.Clear");
+                deleteMultiple.Click += (_, ev) =>
+                {
+                    if (repo.CanCreatePopup())
+                        repo.ShowPopup(new ViewModels.DeleteMultipleTags(repo, selected));
+
+                    ev.Handled = true;
+                };
+
+                var menu = new ContextMenu();
+                menu.Items.Add(deleteMultiple);
+                menu.Open(listBox);
             }
 
             e.Handled = true;
@@ -298,15 +358,25 @@ namespace SourceGit.Views
 
         private void OnSelectionChanged(object sender, SelectionChangedEventArgs _)
         {
-            var selected = (sender as ListBox)?.SelectedItem;
-            Models.Tag selectedTag = null;
-            if (selected is ViewModels.TagTreeNode node)
-                selectedTag = node.Tag;
-            else if (selected is Models.Tag tag)
-                selectedTag = tag;
+            if (sender is not ListBox listBox)
+                return;
+
+            if (listBox.SelectedItems is { Count: 0 })
+            {
+                if (Content is ViewModels.TagCollectionAsList list)
+                    list.ClearSelection();
+                else if (Content is ViewModels.TagCollectionAsTree tree)
+                    tree.ClearSelection();
+            }
+            else if (listBox.SelectedItems is { Count: > 0 })
+            {
+                if (Content is ViewModels.TagCollectionAsList list)
+                    list.UpdateSelection(listBox.SelectedItems);
+                else if (Content is ViewModels.TagCollectionAsTree tree)
+                    tree.UpdateSelection(listBox.SelectedItems);
 
-            if (selectedTag != null)
                 RaiseEvent(new RoutedEventArgs(SelectionChangedEvent));
+            }
         }
 
         private void OnKeyDown(object sender, KeyEventArgs e)
@@ -320,10 +390,24 @@ namespace SourceGit.Views
             var selected = (sender as ListBox)?.SelectedItem;
             if (selected is ViewModels.TagTreeNode { Tag: { } tagInNode })
                 repo.DeleteTag(tagInNode);
-            else if (selected is Models.Tag tag)
-                repo.DeleteTag(tag);
+            else if (selected is ViewModels.TagListItem { Tag: { } tagInItem })
+                repo.DeleteTag(tagInItem);
 
             e.Handled = true;
         }
+
+        private void CollectTagsInNode(ViewModels.TagTreeNode node, List<Models.Tag> outs)
+        {
+            if (node.Tag is { } tag)
+            {
+                if (!outs.Contains(tag))
+                    outs.Add(tag);
+
+                return;
+            }
+
+            foreach (var child in node.Children)
+                CollectTagsInNode(child, outs);
+        }
     }
 }
